==> nomachine-7.6.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/Common/NXTime.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2021 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub Common::NXTime::getSecondsSinceEpoch{package Common::NXTime;no warnings;(my $seconds
=libnxh::NXGetTime ());return ($seconds);}sub 
Common::NXTime::getSecondsAndMicrosecondsSinceEpoch{package Common::NXTime;no 
warnings;(my $buffer=("\x3a" x (0x1c78+ 1546-0x225a)));my (@arr);my (@result);(my $retval
=libnxh::NXSecondsAndMicrosecondsSinceEpoch ($buffer));if (($retval!=(-
(0x0dd0+ 4488-0x1f57)))){(@arr=split ( /:/ ,$buffer,(0x06a5+ 5656-0x1cbd)));(
@result=splice (@arr,(0x0ec6+ 4747-0x2151),(0x0810+ 2637-0x125b)));return (
@result);}else{(my $errorNumber=libnxh::NXGetError ());(my $errorString=
libnxh::NXGetErrorString ());syswrite (STDERR,
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x67\x65\x74\x20\x63\x75\x72\x72\x65\x6e\x74\x20\x74\x69\x6d\x65\x20\x77\x69\x74\x68\x20\x6d\x69\x63\x72\x6f\x73\x65\x63\x6f\x6e\x64\x20\x70\x72\x65\x63\x69\x73\x69\x6f\x6e\x2e\x0a"
);syswrite (STDERR,((((
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20\x27").$errorString)."\x27\x2e\x0a"));main::nxexit ();}}
sub Common::NXTime::getMillisecondsSinceEpoch{package Common::NXTime;no warnings
;(my ($seconds,$microseconds)=getSecondsAndMicrosecondsSinceEpoch ());(my $milliseconds
=int ((($seconds *(0x0dc2+ 2870-0x1510))+($microseconds/(0x1041+ 4514-0x1dfb))))
);return ($milliseconds);}sub Common::NXTime::getLocalTime{package 
Common::NXTime;no warnings;my (@arr);my (@result);(my $buffer=("\x3a" x 
(0x0499+ 438-0x0627)));(my $retval=libnxh::NXLocalTime ($buffer));if (($retval!=
(-(0x161b+ 3326-0x2318)))){(@arr=split ( /:/ ,$buffer,(0x0af4+ 5479-0x205b)));(
@result=splice (@arr,(0x14f9+ 4089-0x24f2),(0x1a12+ 3174-0x266f)));return (
@result);}else{(my $errorNumber=libnxh::NXGetError ());(my $errorString=
libnxh::NXGetErrorString ());syswrite (STDERR,
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x67\x65\x74\x20\x63\x75\x72\x72\x65\x6e\x74\x20\x74\x69\x6d\x65\x2e\x0a"
);syswrite (STDERR,((((
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20\x27").$errorString)."\x27\x2e\x0a"));main::nxexit ();}}
sub Common::NXTime::getLocalTimeFromTimestamp{package Common::NXTime;no warnings
;(my $stamp=shift (@_));my (@arr);my (@result);(my $buffer=("\x3a" x 
(0x0506+ 5956-0x1c22)));(my $retval=libnxh::NXLocalTimeFromTimestamp ($stamp,
$buffer));if (($retval!=(-(0x07eb+ 3556-0x15ce)))){(@arr=split ( /:/ ,$buffer,
(0x009b+ 8309-0x2110)));(@result=splice (@arr,(0x02f2+ 7894-0x21c8),
(0x0683+ 8099-0x261d)));return (@result);}else{(my $errorNumber=
libnxh::NXGetError ());(my $errorString=libnxh::NXGetErrorString ());syswrite (
STDERR,((
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x67\x65\x74\x20\x63\x75\x72\x72\x65\x6e\x74\x20\x74\x69\x6d\x65\x2e\x20\x41\x72\x67\x75\x6d\x65\x6e\x74\x20\x69\x73\x20"
.$stamp)."\x2e\x0a"));syswrite (STDERR,((((
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20\x27").$errorString)."\x27\x2e\x0a"));main::nxexit ();}}
sub Common::NXTime::getDateString{package Common::NXTime;no warnings;(my $string
=libnxh::NXLocalTimeAsString ());return ($string);}sub 
Common::NXTime::getTimestamp{package Common::NXTime;no warnings;(my ($sec,
$microsec)=getSecondsAndMicrosecondsSinceEpoch ());(my (@time)=
getLocalTimeFromTimestamp ($sec));(my $milisec=sprintf ("\x25\x30\x36\x64",
$microsec));($milisec=((substr ($milisec,(0x09f9+ 6076-0x21b5),
(0x0075+ 1573-0x0697))."\x2e").substr ($milisec,(0x0c12+ 3452-0x198b))));(my $Timestamp
=((((((sprintf ("\x25\x30\x32\x64",$time[(0x109a+ 3898-0x1fd2)])."\x3a").sprintf
 ("\x25\x30\x32\x64",$time[(0x09df+ 4436-0x1b32)]))."\x3a").sprintf (
"\x25\x30\x32\x64",$time[(0x08a6+ 6360-0x217e)]))."\x3a").sprintf ($milisec)));
return ($Timestamp);}sub Common::NXTime::getTimestampOnlyMicroseconds{package 
Common::NXTime;no warnings;(my ($sec,$microsec)=
getSecondsAndMicrosecondsSinceEpoch ());(my $milisec=sprintf ("\x25\x30\x36\x64"
,$microsec));($milisec=((substr ($milisec,(0x00d4+ 4318-0x11b2),
(0x1bd5+ 1160-0x205a))."\x2e").substr ($milisec,(0x19cf+ 2136-0x2224))));(my $Timestamp
=sprintf ($milisec));return ($Timestamp);}sub Common::NXTime::__getTimeMs{
package Common::NXTime;no warnings;(my ($sec,$microsec)=
getSecondsAndMicrosecondsSinceEpoch ());(my (@time)=getLocalTimeFromTimestamp (
$sec));(my $milisec=sprintf ("\x25\x30\x36\x64",$microsec));($milisec=(substr (
$milisec,(0x0c41+ 5472-0x21a1),(0x0f38+ 1055-0x1354)).substr ($milisec,
(0x0c37+ 949-0x0fe9))));return ($milisec,@time);}sub Common::NXTime::getTimeMs{
package Common::NXTime;no warnings;(my ($milisec,@time)=__getTimeMs ());(my $TimeMs
=((((sprintf ("\x25\x30\x32\x64",$time[(0x0353+ 6888-0x1e39)]).sprintf (
"\x25\x30\x32\x64",$time[(0x11ec+ 4885-0x2500)])).sprintf ("\x25\x30\x32\x64",
$time[(0x030d+ 3286-0x0fe3)]))."\x2e").sprintf ($milisec)));return ($TimeMs);}
sub Common::NXTime::getLoggerTimeline{package Common::NXTime;no warnings;(my (
$milisec,@time)=__getTimeMs ());($milisec=((substr ($milisec,
(0x07f2+ 5855-0x1ed1),(0x1428+ 4037-0x23ea))."\x2e").substr ($milisec,
(0x0dcd+ 2494-0x1788))));(my $Timeline=(sprintf (
"\x25\x30\x34\x64\x2d\x25\x30\x32\x64\x2d\x25\x30\x32\x64\x20\x25\x30\x32\x64\x3a\x25\x30\x32\x64\x3a\x25\x30\x32\x64\x20"
,((0x1737+ 1993-0x1794)+$time[(0x00a7+ 7924-0x1f96)]),((0x1c0c+ 1531-0x2206)+
$time[(0x1178+ 4994-0x24f6)]),$time[(0x17b4+ 243-0x18a4)],$time[
(0x08dc+ 2650-0x1334)],$time[(0x17a7+ 3246-0x2454)],$time[(0x0d06+ 6373-0x25eb)]
).$milisec));return ($Timeline);}sub 
Common::NXTime::getLoggerTimelineOnlyMicroseconds{package Common::NXTime;no 
warnings;(my ($milisec,@time)=__getTimeMs ());($milisec=((substr ($milisec,
(0x1c87+ 1350-0x21cd),(0x0b53+ 2542-0x153e))."\x2e").substr ($milisec,
(0x05f7+ 7107-0x21b7))));(my $Timeline=sprintf ($milisec));return ($Timeline);}
sub Common::NXTime::convertLocalTimeFromTimestampToHumanReadableString{package 
Common::NXTime;no warnings;(my $timestamp=shift (@_));(my (@time)=
getLocalTimeFromTimestamp ($timestamp));(my $timeString=sprintf (
"\x25\x30\x34\x64\x2d\x25\x30\x32\x64\x2d\x25\x30\x32\x64\x20\x25\x30\x32\x64\x3a\x25\x30\x32\x64\x3a\x25\x30\x32\x64"
,((0x25fa+ 648-0x2116)+$time[(0x1103+ 2127-0x194d)]),($time[
(0x08b2+ 7420-0x25aa)]+(0x0513+ 2461-0x0eaf)),$time[(0x00b5+ 8656-0x2282)],$time
[(0x08d2+ 7652-0x26b4)],$time[(0x05aa+ 8323-0x262c)],$time[(0x1a62+ 216-0x1b3a)]
));return ($timeString);}sub Common::NXTime::getDateTimeForFileName{package 
Common::NXTime;no warnings;(my $dateTime=getLoggerTimeline ());($dateTime=~ s/ [^ ]*$// )
;($dateTime=~ s/-/./gm );($dateTime=~ s/:/./gm );($dateTime=~ s/ /-/gm );return 
($dateTime);}sub Common::NXTime::getSecondsInWeek{package Common::NXTime;no 
warnings;return (604800);}sub Common::NXTime::convertSecondsToDaysRounded{
package Common::NXTime;no warnings;(my $seconds=shift (@_));(my $days=($seconds/
86400));($days=(int ($days)+(0x08b2+ 7121-0x2482)));return ($days);}package 
Common::NXTime;no warnings;"\x3f\x3f\x3f";

==> nomachine-7.9.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/Common/NXTime.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub Common::NXTime::getSecondsSinceEpoch{package Common::NXTime;no warnings;(my $seconds
=libnxh::NXGetTime ());return ($seconds);}sub 
Common::NXTime::getSecondsAndMicrosecondsSinceEpoch{package Common::NXTime;no 
warnings;(my $buffer=("\x3a" x (0x1fb7+ 800-0x22af)));my (@arr);my (@result);(my $retval
=libnxh::NXSecondsAndMicrosecondsSinceEpoch ($buffer));if (($retval!=(-
(0x02fa+ 2688-0x0d79)))){(@arr=split ( /:/ ,$buffer,(0x0ca0+ 2490-0x165a)));(
@result=splice (@arr,(0x112b+ 2755-0x1bee),(0x02b4+ 7031-0x1e29)));return (
@result);}else{(my $errorNumber=libnxh::NXGetError ());(my $errorString=
libnxh::NXGetErrorString ());syswrite (STDERR,
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x67\x65\x74\x20\x63\x75\x72\x72\x65\x6e\x74\x20\x74\x69\x6d\x65\x20\x77\x69\x74\x68\x20\x6d\x69\x63\x72\x6f\x73\x65\x63\x6f\x6e\x64\x20\x70\x72\x65\x63\x69\x73\x69\x6f\x6e\x2e\x0a"
);syswrite (STDERR,((((
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20\x27").$errorString)."\x27\x2e\x0a"));main::nxexit ();}}
sub Common::NXTime::getMillisecondsSinceEpoch{package Common::NXTime;no warnings
;(my ($seconds,$microseconds)=getSecondsAndMicrosecondsSinceEpoch ());(my $milliseconds
=int ((($seconds *(0x1839+ 4053-0x2426))+($microseconds/(0x0fc9+ 2282-0x14cb))))
);return ($milliseconds);}sub Common::NXTime::getLocalTime{package 
Common::NXTime;no warnings;my (@arr);my (@result);(my $buffer=("\x3a" x 
(0x0daf+ 2816-0x1887)));(my $retval=libnxh::NXLocalTime ($buffer));if (($retval
!=(-(0x0c45+ 1155-0x10c7)))){(@arr=split ( /:/ ,$buffer,(0x0319+ 2192-0x0ba9)));
(@result=splice (@arr,(0x1921+ 2763-0x23ec),(0x0898+ 7137-0x2470)));return (
@result);}else{(my $errorNumber=libnxh::NXGetError ());(my $errorString=
libnxh::NXGetErrorString ());syswrite (STDERR,
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x67\x65\x74\x20\x63\x75\x72\x72\x65\x6e\x74\x20\x74\x69\x6d\x65\x2e\x0a"
);syswrite (STDERR,((((
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20\x27").$errorString)."\x27\x2e\x0a"));main::nxexit ();}}
sub Common::NXTime::getLocalTimeFromTimestamp{package Common::NXTime;no warnings
;(my $stamp=shift (@_));my (@arr);my (@result);(my $buffer=("\x3a" x 
(0x1626+ 2888-0x2146)));(my $retval=libnxh::NXLocalTimeFromTimestamp ($stamp,
$buffer));if (($retval!=(-(0x00d9+ 2882-0x0c1a)))){(@arr=split ( /:/ ,$buffer,
(0x0642+ 3350-0x1358)));(@result=splice (@arr,(0x1357+ 4725-0x25cc),
(0x05ac+ 5413-0x1ac8)));return (@result);}else{(my $errorNumber=
libnxh::NXGetError ());(my $errorString=libnxh::NXGetErrorString ());syswrite (
STDERR,((
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x67\x65\x74\x20\x63\x75\x72\x72\x65\x6e\x74\x20\x74\x69\x6d\x65\x2e\x20\x41\x72\x67\x75\x6d\x65\x6e\x74\x20\x69\x73\x20"
.$stamp)."\x2e\x0a"));syswrite (STDERR,((((
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20\x27").$errorString)."\x27\x2e\x0a"));main::nxexit ();}}
sub Common::NXTime::getDateString{package Common::NXTime;no warnings;(my $string
=libnxh::NXLocalTimeAsString ());return ($string);}sub 
Common::NXTime::getTimestamp{package Common::NXTime;no warnings;(my ($sec,
$microsec)=getSecondsAndMicrosecondsSinceEpoch ());(my (@time)=
getLocalTimeFromTimestamp ($sec));(my $milisec=sprintf ("\x25\x30\x36\x64",
$microsec));($milisec=((substr ($milisec,(0x1e9c+ 483-0x207f),
(0x1286+ 1636-0x18e7))."\x2e").substr ($milisec,(0x23ef+  93-0x2449))));(my $Timestamp
=((((((sprintf ("\x25\x30\x32\x64",$time[(0x1fe3+ 117-0x2056)])."\x3a").sprintf 
("\x25\x30\x32\x64",$time[(0x0f82+ 3750-0x1e27)]))."\x3a").sprintf (
"\x25\x30\x32\x64",$time[(0x0920+ 1200-0x0dd0)]))."\x3a").sprintf ($milisec)));
return ($Timestamp);}sub Common::NXTime::getTimestampOnlyMicroseconds{package 
Common::NXTime;no warnings;(my ($sec,$microsec)=
getSecondsAndMicrosecondsSinceEpoch ());(my $milisec=sprintf ("\x25\x30\x36\x64"
,$microsec));($milisec=((substr ($milisec,(0x0ab1+ 3141-0x16f6),
(0x0583+ 3349-0x1295))."\x2e").substr ($milisec,(0x0ee6+ 5809-0x2594))));(my $Timestamp
=sprintf ($milisec));return ($Timestamp);}sub Common::NXTime::__getTimeMs{
package Common::NXTime;no warnings;(my ($sec,$microsec)=
getSecondsAndMicrosecondsSinceEpoch ());(my (@time)=getLocalTimeFromTimestamp (
$sec));(my $milisec=sprintf ("\x25\x30\x36\x64",$microsec));($milisec=(substr (
$milisec,(0x20d9+ 1582-0x2707),(0x0c8c+ 3594-0x1a93)).substr ($milisec,
(0x1910+ 2794-0x23f7))));return ($milisec,@time);}sub Common::NXTime::getTimeMs{
package Common::NXTime;no warnings;(my ($milisec,@time)=__getTimeMs ());(my $TimeMs
=((((sprintf ("\x25\x30\x32\x64",$time[(0x0fbf+ 2981-0x1b62)]).sprintf (
"\x25\x30\x32\x64",$time[(0x121a+ 4956-0x2575)])).sprintf ("\x25\x30\x32\x64",
$time[(0x1515+ 648-0x179d)]))."\x2e").sprintf ($milisec)));return ($TimeMs);}sub
 Common::NXTime::getLoggerTimeline{package Common::NXTime;no warnings;(my (
$milisec,@time)=__getTimeMs ());($milisec=((substr ($milisec,
(0x1b3f+ 1027-0x1f42),(0x0910+ 5144-0x1d25))."\x2e").substr ($milisec,
(0x193b+ 933-0x1cdd))));(my $Timeline=(sprintf (
"\x25\x30\x34\x64\x2d\x25\x30\x32\x64\x2d\x25\x30\x32\x64\x20\x25\x30\x32\x64\x3a\x25\x30\x32\x64\x3a\x25\x30\x32\x64\x20"
,((0x1d16+ 1244-0x1a86)+$time[(0x0d4d+ 1576-0x1370)]),((0x0816+ 7767-0x266c)+
$time[(0x1da0+ 356-0x1f00)]),$time[(0x094a+ 3699-0x17ba)],$time[
(0x1e0c+ 533-0x201f)],$time[(0x0cb7+ 2436-0x163a)],$time[(0x061b+ 1821-0x0d38)])
.$milisec));return ($Timeline);}sub 
Common::NXTime::getLoggerTimelineOnlyMicroseconds{package Common::NXTime;no 
warnings;(my ($milisec,@time)=__getTimeMs ());($milisec=((substr ($milisec,
(0x0577+ 2041-0x0d70),(0x11e4+ 4142-0x220f))."\x2e").substr ($milisec,
(0x0535+ 2591-0x0f51))));(my $Timeline=sprintf ($milisec));return ($Timeline);}
sub Common::NXTime::convertLocalTimeFromTimestampToHumanReadableString{package 
Common::NXTime;no warnings;(my $timestamp=shift (@_));(my (@time)=
getLocalTimeFromTimestamp ($timestamp));(my $timeString=sprintf (
"\x25\x30\x34\x64\x2d\x25\x30\x32\x64\x2d\x25\x30\x32\x64\x20\x25\x30\x32\x64\x3a\x25\x30\x32\x64\x3a\x25\x30\x32\x64"
,((0x2397+ 935-0x1fd2)+$time[(0x23e9+ 706-0x26a6)]),($time[(0x1374+ 690-0x1622)]
+(0x11e5+ 875-0x154f)),$time[(0x1686+ 3128-0x22bb)],$time[(0x15f1+ 3890-0x2521)]
,$time[(0x2017+ 1225-0x24df)],$time[(0x047b+ 6852-0x1f3f)]));return ($timeString
);}sub Common::NXTime::getDateTimeForFileName{package Common::NXTime;no warnings
;(my $dateTime=getLoggerTimeline ());($dateTime=~ s/ [^ ]*$// );($dateTime=~ s/-/./gm )
;($dateTime=~ s/:/./gm );($dateTime=~ s/ /-/gm );return ($dateTime);}sub 
Common::NXTime::getSecondsInWeek{package Common::NXTime;no warnings;return (
604800);}sub Common::NXTime::convertSecondsToDaysRounded{package Common::NXTime;
no warnings;(my $seconds=shift (@_));(my $days=($seconds/86400));($days=(int (
$days)+(0x1949+ 3483-0x26e3)));return ($days);}package Common::NXTime;no 
warnings;"\x3f\x3f\x3f";
